@@ -51,6 +51,10 @@ class Segments:
         :type value: str or int or float
 
         """
+        # Attempt to round off so we can still display the value
+        if isinstance(value, float) and len(str(value)) > 5:
+            value = round(value)
+
         self._segments.print(value)
         self._segments.show()
 
@@ -97,8 +101,10 @@ class Segments:
         Brightness returns the current display brightness.
         0-15 = Dimmest to Brightest Setting
         """
-        return self._segments.brightness
+        return round(self._segments.brightness * 15)
 
     @brightness.setter
     def brightness(self, brightness):
-        self._segments.brightness = brightness
+        if not 0 <= brightness <= 15:
+            raise ValueError('Brightness must be a value between 0 and 15')
+        self._segments.brightness = brightness / 15
